@@ -1,8 +1,5 @@
+import logging
 import multiprocessing
-import os
-import time
-
-start = time.time()
 
 class SharedValue(object):
     """A multi-process shared value with automatic lock"""
@@ -103,8 +100,7 @@ class SharedValue(object):
 
     def _debug(self, operation):
         if self.name:
-            global start
-            print(f"DEBUG {time.time()-start:.3f} [{os.getpid()}] {self.name} > {operation} : {self._val.value}")
+            logging.debug(f"{self.name} > {operation} : {self._val.value}")
 
     def _get(self, v):
         if self._type(v):
