@@ -8,7 +8,6 @@ from prometheus_client import *
 
 start = time.time()
 
-
 class Timer():
     def __init__(self, name,
                  _text="{}# {}. Elapsed time: {:0.4f} seconds", _logger=print,
@@ -26,7 +25,7 @@ class Timer():
         else:
             self._count = Counter(f'operations_{self.name}_count', f'Total count for timer', self.labels)
             self._failed = Counter(f'operations_{self.name}_failed', f'Total failed for timer', self.labels)
-            self._latency = Histogram(f'operations_{self.name}_latency', f'Latency for timer', self.labels)
+            self._latency = Summary(f'operations_{self.name}_latency', f'Latency for timer', self.labels)
             self._in_progress = Gauge(f'operations_{self.name}_in_progress', f'Operations in progress', self.labels)
 
     def text(self, _text):
