@@ -2,11 +2,8 @@ import asyncio
 import datetime
 import logging
 import os
-import sys
 import time
-import traceback
 from asyncio.locks import BoundedSemaphore
-from random import randint
 
 from lemmings.task_set_run import TaskSetRun
 from lemmings.utils import _num, duration2sec, exception_with_line, Summary, timed_execution
@@ -55,7 +52,7 @@ class Worker:
         await asyncio.sleep(d)
         delay = time.time() - begin - d
         if delay > 1: # difference more than 1 sec
-            logging.warning(f"running late task {name} [delay: {delay:.2f}], scheduled at {d:.2f} | {offset}")
+            # logging.warning(f"running late task {name} [delay: {delay:.2f}], scheduled at {d:.2f} | {offset}")
             task_delay_latency.labels(task=name, process=os.getpid(), process_group=os.getppid()).observe(delay)
 
     async def run_task(self, offset, task):
